@@ -506,7 +506,7 @@ class DCTransformsTest(AssertsCompiledSQL, fixtures.TestBase):
         class B(A):
             b_data: Mapped[str] = mapped_column(default="bd")
 
-        # ensure we didnt break dataclasses contract of removing Field
+        # ensure we didn't break dataclasses contract of removing Field
         # issue #8880
         eq_(A.__dict__["some_field"], 5)
         assert "ctrl_one" not in A.__dict__
@@ -922,6 +922,7 @@ class DCTransformsTest(AssertsCompiledSQL, fixtures.TestBase):
         is_true("id" in sig.parameters)
         is_true("content" in sig.parameters)
         is_true("user_id" in sig.parameters)
+        is_true("user" in sig.parameters)
 
 
 class RelationshipDefaultFactoryTest(fixtures.TestBase):
