@@ -1,6 +1,7 @@
 from __future__ import annotations
 
 import contextlib
+import datetime
 from typing import Any
 from typing import List
 from typing import Optional
@@ -8,8 +9,10 @@ from typing import Set
 import uuid
 
 from sqlalchemy import bindparam
+from sqlalchemy import Computed
 from sqlalchemy import event
 from sqlalchemy import exc
+from sqlalchemy import FetchedValue
 from sqlalchemy import ForeignKey
 from sqlalchemy import func
 from sqlalchemy import Identity
@@ -37,22 +40,26 @@ from sqlalchemy.orm import relationship
 from sqlalchemy.orm import selectinload
 from sqlalchemy.orm import Session
 from sqlalchemy.orm import subqueryload
+from sqlalchemy.sql import coercions
+from sqlalchemy.sql import roles
 from sqlalchemy.testing import config
 from sqlalchemy.testing import eq_
 from sqlalchemy.testing import expect_deprecated
 from sqlalchemy.testing import expect_raises_message
 from sqlalchemy.testing import expect_warnings
 from sqlalchemy.testing import fixtures
+from sqlalchemy.testing import is_
 from sqlalchemy.testing import mock
 from sqlalchemy.testing import provision
 from sqlalchemy.testing.assertsql import CompiledSQL
 from sqlalchemy.testing.assertsql import Conditional
 from sqlalchemy.testing.entities import ComparableEntity
 from sqlalchemy.testing.fixtures import fixture_session
+from sqlalchemy.types import NullType
 
 
 class InsertStmtTest(testing.AssertsExecutionResults, fixtures.TestBase):
-    __backend__ = True
+    __sparse_driver_backend__ = True
 
     @testing.variation(
         "style",
@@ -275,6 +282,86 @@ class InsertStmtTest(testing.AssertsExecutionResults, fixtures.TestBase):
             ),
         )
 
+    @testing.requires.insert_returning
+    @testing.variation(
+        "insert_type",
+        [("values", testing.requires.multivalues_inserts), "bulk"],
+    )
+    def test_returning_col_property(
+        self, decl_base, insert_type: testing.Variation
+    ):
+        """test #12326"""
+
+        class User(ComparableEntity, decl_base):
+            __tablename__ = "user"
+
+            id: Mapped[int] = mapped_column(
+                primary_key=True, autoincrement=False
+            )
+            name: Mapped[str]
+            age: Mapped[int]
+
+        decl_base.metadata.create_all(testing.db)
+
+        a_alias = aliased(User)
+        User.colprop = column_property(
+            select(func.max(a_alias.age))
+            .where(a_alias.id != User.id)
+            .scalar_subquery()
+        )
+
+        sess = fixture_session()
+
+        if insert_type.values:
+            stmt = insert(User).values(
+                [
+                    dict(id=1, name="john", age=25),
+                    dict(id=2, name="jack", age=47),
+                    dict(id=3, name="jill", age=29),
+                    dict(id=4, name="jane", age=37),
+                ],
+            )
+            params = None
+        elif insert_type.bulk:
+            stmt = insert(User)
+            params = [
+                dict(id=1, name="john", age=25),
+                dict(id=2, name="jack", age=47),
+                dict(id=3, name="jill", age=29),
+                dict(id=4, name="jane", age=37),
+            ]
+        else:
+            insert_type.fail()
+
+        stmt = stmt.returning(User)
+
+        result = sess.execute(stmt, params=params)
+
+        # the RETURNING doesn't have the column property in it.
+        # so to load these, they are all lazy loaded
+        with self.sql_execution_asserter() as asserter:
+            eq_(
+                result.scalars().all(),
+                [
+                    User(id=1, name="john", age=25, colprop=47),
+                    User(id=2, name="jack", age=47, colprop=37),
+                    User(id=3, name="jill", age=29, colprop=47),
+                    User(id=4, name="jane", age=37, colprop=47),
+                ],
+            )
+
+        # assert they're all lazy loaded
+        asserter.assert_(
+            *[
+                CompiledSQL(
+                    'SELECT (SELECT max(user_1.age) AS max_1 FROM "user" '
+                    'AS user_1 WHERE user_1.id != "user".id) AS anon_1 '
+                    'FROM "user" WHERE "user".id = :pk_1'
+                )
+                for i in range(4)
+            ]
+        )
+
     @testing.requires.insert_returning
     @testing.requires.returning_star
     @testing.variation(
@@ -600,7 +687,104 @@ class InsertStmtTest(testing.AssertsExecutionResults, fixtures.TestBase):
 
 
 class UpdateStmtTest(testing.AssertsExecutionResults, fixtures.TestBase):
-    __backend__ = True
+    __sparse_driver_backend__ = True
+
+    @testing.variation(
+        "use_onupdate",
+        [
+            "none",
+            "server",
+            "callable",
+            "clientsql",
+            ("computed", testing.requires.computed_columns),
+        ],
+    )
+    def test_bulk_update_onupdates(
+        self,
+        decl_base,
+        use_onupdate,
+    ):
+        """assert that for now, bulk ORM update by primary key does not
+        expire or refresh onupdates."""
+
+        class Employee(ComparableEntity, decl_base):
+            __tablename__ = "employee"
+
+            uuid: Mapped[uuid.UUID] = mapped_column(primary_key=True)
+            user_name: Mapped[str] = mapped_column(String(200), nullable=False)
+
+            if use_onupdate.server:
+                some_server_value: Mapped[str] = mapped_column(
+                    server_onupdate=FetchedValue()
+                )
+            elif use_onupdate.callable:
+                some_server_value: Mapped[str] = mapped_column(
+                    onupdate=lambda: "value 2"
+                )
+            elif use_onupdate.clientsql:
+                some_server_value: Mapped[str] = mapped_column(
+                    onupdate=literal("value 2")
+                )
+            elif use_onupdate.computed:
+                some_server_value: Mapped[str] = mapped_column(
+                    String(255),
+                    Computed(user_name + " computed value"),
+                    nullable=True,
+                )
+            else:
+                some_server_value: Mapped[str]
+
+        decl_base.metadata.create_all(testing.db)
+        s = fixture_session()
+
+        uuid1 = uuid.uuid4()
+
+        if use_onupdate.computed:
+            server_old_value, server_new_value = (
+                "e1 old name computed value",
+                "e1 new name computed value",
+            )
+            e1 = Employee(uuid=uuid1, user_name="e1 old name")
+        else:
+            server_old_value, server_new_value = ("value 1", "value 2")
+            e1 = Employee(
+                uuid=uuid1,
+                user_name="e1 old name",
+                some_server_value="value 1",
+            )
+        s.add(e1)
+        s.flush()
+
+        # for computed col, make sure e1.some_server_value is loaded.
+        # this will already be the case for all RETURNING backends, so this
+        # suits just MySQL.
+        if use_onupdate.computed:
+            e1.some_server_value
+
+        stmt = update(Employee)
+
+        # perform out of band UPDATE on server value to simulate
+        # a computed col
+        if use_onupdate.none or use_onupdate.server:
+            s.connection().execute(
+                update(Employee.__table__).values(some_server_value="value 2")
+            )
+
+        execution_options = {}
+
+        s.execute(
+            stmt,
+            execution_options=execution_options,
+            params=[{"uuid": uuid1, "user_name": "e1 new name"}],
+        )
+
+        assert "some_server_value" in e1.__dict__
+        eq_(e1.some_server_value, server_old_value)
+
+        # do a full expire, now the new value is definitely there
+        s.commit()
+        s.expire_all()
+        eq_(e1.some_server_value, server_new_value)
 
     @testing.variation(
         "returning_executemany",
@@ -981,6 +1165,47 @@ class UpdateStmtTest(testing.AssertsExecutionResults, fixtures.TestBase):
             ],
         )
 
+    @testing.requires.update_returning
+    def test_returning_col_property(self, decl_base):
+        """test #12326"""
+
+        class User(ComparableEntity, decl_base):
+            __tablename__ = "user"
+
+            id: Mapped[int] = mapped_column(
+                primary_key=True, autoincrement=False
+            )
+            name: Mapped[str]
+            age: Mapped[int]
+
+        decl_base.metadata.create_all(testing.db)
+
+        a_alias = aliased(User)
+        User.colprop = column_property(
+            select(func.max(a_alias.age))
+            .where(a_alias.id != User.id)
+            .scalar_subquery()
+        )
+
+        sess = fixture_session()
+
+        sess.execute(
+            insert(User),
+            [
+                dict(id=1, name="john", age=25),
+                dict(id=2, name="jack", age=47),
+                dict(id=3, name="jill", age=29),
+                dict(id=4, name="jane", age=37),
+            ],
+        )
+
+        stmt = (
+            update(User).values(age=30).where(User.age == 29).returning(User)
+        )
+
+        row = sess.execute(stmt).one()
+        eq_(row[0], User(id=3, name="jill", age=30, colprop=47))
+
 
 class BulkDMLReturningInhTest:
     use_sentinel = False
@@ -1997,7 +2222,7 @@ class BulkDMLReturningJoinedInhTest(
     BulkDMLReturningInhTest, fixtures.DeclarativeMappedTest
 ):
     __requires__ = ("insert_returning", "insert_executemany_returning")
-    __backend__ = True
+    __sparse_driver_backend__ = True
 
     use_sentinel = False
     randomize_returning = False
@@ -2114,7 +2339,7 @@ class BulkDMLReturningSingleInhTest(
     BulkDMLReturningInhTest, fixtures.DeclarativeMappedTest
 ):
     __requires__ = ("insert_returning", "insert_executemany_returning")
-    __backend__ = True
+    __sparse_driver_backend__ = True
 
     @classmethod
     def setup_classes(cls):
@@ -2157,7 +2382,7 @@ class BulkDMLReturningConcreteInhTest(
     BulkDMLReturningInhTest, fixtures.DeclarativeMappedTest
 ):
     __requires__ = ("insert_returning", "insert_executemany_returning")
-    __backend__ = True
+    __sparse_driver_backend__ = True
 
     @classmethod
     def setup_classes(cls):
@@ -2197,7 +2422,7 @@ class BulkDMLReturningConcreteInhTest(
 
 class CTETest(fixtures.DeclarativeMappedTest):
     __requires__ = ("insert_returning", "ctes_on_dml")
-    __backend__ = True
+    __sparse_driver_backend__ = True
 
     @classmethod
     def setup_classes(cls):
@@ -2320,18 +2545,24 @@ class EagerLoadTest(
 
         class A(Base):
             __tablename__ = "a"
-            id: Mapped[int] = mapped_column(Integer, primary_key=True)
+            id: Mapped[int] = mapped_column(
+                Integer, Identity(), primary_key=True
+            )
             cs = relationship("C")
 
         class B(Base):
             __tablename__ = "b"
-            id: Mapped[int] = mapped_column(Integer, primary_key=True)
+            id: Mapped[int] = mapped_column(
+                Integer, Identity(), primary_key=True
+            )
             a_id: Mapped[int] = mapped_column(ForeignKey("a.id"))
             a = relationship("A")
 
         class C(Base):
             __tablename__ = "c"
-            id: Mapped[int] = mapped_column(Integer, primary_key=True)
+            id: Mapped[int] = mapped_column(
+                Integer, Identity(), primary_key=True
+            )
             a_id: Mapped[int] = mapped_column(ForeignKey("a.id"))
 
     @classmethod
@@ -2510,3 +2741,76 @@ class EagerLoadTest(
                 b3 = sess.scalar(stmt, [{"a_id": 3}])
 
                 eq_({c.id for c in b3.a.cs}, {3, 4})
+
+
+class DMLCompileScenariosTest(testing.AssertsCompiledSQL, fixtures.TestBase):
+    __dialect__ = "default_enhanced"  # for UPDATE..FROM
+
+    @testing.variation("style", ["insert", "upsert"])
+    def test_insert_values_from_primary_table_only(self, decl_base, style):
+        """test for #12692"""
+
+        class A(decl_base):
+            __tablename__ = "a"
+            id: Mapped[int] = mapped_column(Identity(), primary_key=True)
+            data: Mapped[int]
+
+        class B(decl_base):
+            __tablename__ = "b"
+            id: Mapped[int] = mapped_column(Identity(), primary_key=True)
+            data: Mapped[str]
+
+        stmt = insert(A.__table__)
+
+        # we're trying to exercise codepaths in orm/bulk_persistence.py that
+        # would only apply to an insert() statement against the ORM entity,
+        # e.g. insert(A).  In the update() case, the WHERE clause can also
+        # pull in the ORM entity, which is how we found the issue here, but
+        # for INSERT there's no current method that does this; returning()
+        # could do this in theory but currently doesn't.  So for now, cheat,
+        # and pretend there's some conversion that's going to propagate
+        # from an ORM expression
+        coercions.expect(
+            roles.WhereHavingRole, B.id == 5, apply_propagate_attrs=stmt
+        )
+
+        if style.insert:
+            stmt = stmt.values(data=123)
+
+            # assert that the ORM did not get involved, putting B.data as the
+            # key in the dictionary
+            is_(stmt._values["data"].type._type_affinity, NullType)
+        elif style.upsert:
+            stmt = stmt.values([{"data": 123}, {"data": 456}])
+
+            # assert that the ORM did not get involved, putting B.data as the
+            # keys in the dictionaries
+            eq_(stmt._multi_values, ([{"data": 123}, {"data": 456}],))
+        else:
+            style.fail()
+
+    def test_update_values_from_primary_table_only(self, decl_base):
+        """test for #12692"""
+
+        class A(decl_base):
+            __tablename__ = "a"
+            id: Mapped[int] = mapped_column(Identity(), primary_key=True)
+            data: Mapped[str]
+            updated_at: Mapped[datetime.datetime] = mapped_column(
+                onupdate=func.now()
+            )
+
+        class B(decl_base):
+            __tablename__ = "b"
+            id: Mapped[int] = mapped_column(Identity(), primary_key=True)
+            data: Mapped[str]
+            updated_at: Mapped[datetime.datetime] = mapped_column(
+                onupdate=func.now()
+            )
+
+        stmt = update(A.__table__).where(B.id == 1).values(data="some data")
+        self.assert_compile(
+            stmt,
+            "UPDATE a SET data=:data, updated_at=now() "
+            "FROM b WHERE b.id = :id_1",
+        )
